#

##

##

    	L2

    	summary

    		These are things that should be in an L2
    		and not an L1.

    	possibilities

    		[ ] friends roster

    		[ ] quarantine lists

    				If a business seems malicious, then
    				they can be added to the Quarantine
    				List.

    					For instance, if they are sending
    					data that if not equal to the data
    					sent by other businesses.